/*
 * NIST HL7 WebService
 * TestPVAxis2v1_2.java June 15, 2007
 *
 * This code was produced by the National Institute of Standards and
 * Technology (NIST). See the "nist.disclaimer" file given in the distribution 
 * for information on the use and redistribution of this software.
 */
package main;

import java.io.FileInputStream;
import gov.nist.hl7.ws.validation.messagevalidation.*;
import gov.nist.hl7.ws.validation.messagevalidation.MessageValidationMessageValidationSOAP11PortStub.*;

/**
 * @author Roch Bertucat (NIST)
 * This class is a basic Apache Axis2-implemented client to use 
 * with the NIST validation module web service hosted on http://xreg2.nist.gov:8080/axis2/services/
 */
public class TestMPVAxis2v1_2 {

    /**
     * @param args
     */
    public static void main(String[] args) {
        try {
            // Transform Files to string
            FileInputStream fis = new FileInputStream("files/profile/BadMsgTypeEventTypeCombination.xml");
            byte b[]= new byte[fis.available()];
            fis.read(b);
            String profile = new String(b);
            
            fis = new FileInputStream("files/message/IncorrectEVN.1.MSH.9.MSG.2.xml");
            //fis = new FileInputStream("files/message/ValidProfileForMessageValidation.msg00001.xml");
            b = new byte[fis.available()];
            fis.read(b);
            String message = new String(b);

            fis = new FileInputStream("files/context/MessageValidationContext.xml");
            b = new byte[fis.available()];
            fis.read(b);
            String msgValidContext = new String(b);
            fis.close();
            
            // Create the connector
            MessageValidationMessageValidationSOAP11PortStub pvs = 
                new MessageValidationMessageValidationSOAP11PortStub("http://xreg2.nist.gov:8080/axis2/services/MessageValidation");
//            MessageValidationMessageValidationSOAP11PortStub pvs = 
//                new MessageValidationMessageValidationSOAP11PortStub("http://localhost:8080/axis2/services/MessageValidation");
            
            // Initiate WS Parameters
            SetProfile typeProfile = new SetProfile();
            typeProfile.setParam0(profile);
            
            SetMessage typeMessage = new SetMessage();
            typeMessage.setParam0(message);
            typeMessage.setParam1(true);

            SetMessageValidationContext validationContext = new SetMessageValidationContext();
            validationContext.setParam0(msgValidContext);
            
            // Set files on the WS
            SetMessageResponse respMessage = pvs.setMessage(typeMessage);
            GetLastExceptionMessageResponse respError = pvs.getLastExceptionMessage();
            System.out.println(respError.get_return());
            SetProfileResponse respProfile = pvs.setProfile(typeProfile);
            respError = pvs.getLastExceptionMessage();
            System.out.println(respError.get_return());
            
            // Call the validation method
            if (respProfile.get_return() && respMessage.get_return()) {
                ValidateResponse vr = pvs.validate();
                if (vr.get_return()) 
                    System.out.println ("Message Valid");
                else 
                    System.out.println ("Message Not Valid");
            }
            
            respError = pvs.getLastExceptionMessage();
            System.out.println(respError.get_return());
            
            // Display the validation report
            GetMessageValidationReportResponse reportResponse = pvs.getMessageValidationReport();
            System.out.println(reportResponse.get_return());
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
